# metafid
## oxtapus

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/oxtapus)
![PyPI - Version](https://img.shields.io/pypi/v/oxtapus)
![PyPI - Downloads](https://img.shields.io/pypi/dm/oxtapus?logoColor=blue&color=blue)
![GitHub](https://img.shields.io/github/license/yghaderi/oxtapus)

<div dir="rtl">
اُختاپوس برایِ پوششِ بخشی از داده‌هایِ موردِ نیاز در مدل-سازی‌هایِ مالی-اقتصادی توسعه داده شده است.
برایِ یاد-گیریِ بیشتر،
<a href="https://yghaderi.github.io/oxtapus/">
راهنمایِ بهره-گیران
</a>
رو بخونید.
</div>


## install 
#### mac , linux
```bash
python3 -m pip install oxtapus
```
#### windows
```bash
python -m pip install oxtapus
```


## TSETMC (tsetmc.com)

<div dir="rtl">
تقریبن همه‌یِ داده‌هایِ وب-سایتِ tsetmc.com رو پوشش می‌ده. 
<br>
<br>
نمونه
(برای راهنمایِ کامل 
<a href="https://yghaderi.github.io/oxtapus/">
راهنمایِ بهره-گیران
</a>
رو بخونید)
:
</div>

```python
>>> from oxtapus import TSETMC

>>> tsetmc = TSETMC()
>>> tsetmc.intraday_trades("دکپسول")
shape: (190, 4)
┌─────────────────────┬───────────┬─────────┬────────┐
│ datetime            ┆ trade_nbr ┆ price   ┆ volume │
│ ---                 ┆ ---       ┆ ---     ┆ ---    │
│ datetime[μs]        ┆ i64       ┆ f64     ┆ i64    │
╞═════════════════════╪═══════════╪═════════╪════════╡
│ 2023-11-01 09:10:01 ┆ 1         ┆ 75100.0 ┆ 250    │
│ 2023-11-01 09:10:05 ┆ 2         ┆ 75100.0 ┆ 625    │
│ 2023-11-01 09:10:05 ┆ 3         ┆ 75100.0 ┆ 48     │
│ 2023-11-01 09:11:57 ┆ 4         ┆ 75150.0 ┆ 100    │
│ …                   ┆ …         ┆ …       ┆ …      │
│ 2023-11-01 12:28:47 ┆ 187       ┆ 77000.0 ┆ 510    │
│ 2023-11-01 12:28:47 ┆ 188       ┆ 77000.0 ┆ 89     │
│ 2023-11-01 12:29:06 ┆ 189       ┆ 77000.0 ┆ 411    │
│ 2023-11-01 12:29:06 ┆ 190       ┆ 77000.0 ┆ 500    │
└─────────────────────┴───────────┴─────────┴────────┘
```

<h5 dir="rtl">
لیستِ داده‌هایِ قابلِ دریافت:
</h5>
<div dir="rtl">
<li>
دیدبانِ بازار(mw): با واردکردنِ بازار(هایِ) موردِ نیاز آخرین داده‌یِ صفحه‌یِ
<a href="http://main.tsetmc.com/MarketWatch">ِدیدبانِ بازار</a>
رو به همراهِ 5 سفارشِ برتر بهت می‌ده.
</li>

<li>
دیدبانِ بازارِ اخیتارِ-معامله(option-mw): آخرین داده‌یِ صفحه‌یِ
<a href="http://main.tsetmc.com/MarketWatch">ِدیدبانِ بازار</a>
رو به همراهِ 5 سفارشِ برتر، داده‌هایِ داراییِ پایه، قیمتِ اعمال، تاریخِ اعمال، و روز تا سر-رسید بهت می‌ده.
</li>

<li>
داده‌هایِ نماد/ابزار (ins-info): داده‌هایِ پایه‌یِ نماد رو بهت می‌ده.
</li>

<li>
داده‌هایِ خاصِ اختیارِ-معامله (specific-option-data): داده‌هایی که خاصِ نماد‌هایِ اختیارِ-معامله‌ان، مانندِِ موقعیت‌هایِ بازِ و برخی داده‌هایِ دیگه رو بهت می‌ده.
</li>

<li>
تاریخچه‌یِ معامله‌یِ نماد (hist-price): داده‌هایِ مربوط به معامله‌یِ گذشته‌یِ نماد رو بهت میده.
</li>

<li>
تاریخچه‌یِ معامله‌یِ نماد (adj-hist-price): داده‌هایِ مربوط به معامله‌یِ گذشته‌یِ نماد رو به صورتِ تعدیلی و غیرِ-تعدیلی بهت میده.
</li>

<li>
داده‌هایِ درون-روزیِ معامله (intraday-trades): داده‌هایِ مربوط به ریزِ معامله‌یِ آخرین روزِ معامله رو بهت می‌ده.
</li>

<li>
داده‌هایِ درون-روزیِ معامله بر مبنایِ فاصله‌یِ زمانی (intraday-trades-based-on-timeframe): داده‌هایِ مربوط به ریزِ معامله‌یِ آخرین روزِ معامله رو بر مبنایِ تایم-فریمِ وارده شده بهت می‌ده.
</li>

<li>
آخرین داده‌یِ نماد (last-ins-data): برخی از داده‌هایِ صفحه‌یِ اصلیِ نماد- مانندِ وضعیتِ نماد و ... - رو بهت می‌ده.
</li>

<li>
حقیقی-حقوقی (client-type): داده‌هایِ گذشته‌یِ مربوط به معامله‌هایِ حقیقی-حقوقی رو بهت می‌ده.
</li>

<li>
تغییرِ سرمایه (share-change): داده‌هایِ مربوط به تغییرِ سرمایه‌یِ نماد رو بهت می‌ده.
</li>

<li>
شاخص‌ها (indexes): لیستِ همه‌یِ شاخص‌ها و مقدار و تغییرِ مربوط به آخرین روزِ معاملاتی رو بهت می‌ده.
</li>

<li>
نماد‌هایی که شاخص دنبال‌ می‌کنه (symbols-that-index-tracks): نمادهایی که هر شاخص دنبال می‌کنه رو بهت می‌ده.
</li>

<li>
تاریخچه‌یِ شاخص (index-hist): داده‌هایِ مربوط به مقدارِ شاخص‌ها رو بهت می‌ده.
</li>

<li>
تاریخ و زمانِ رو بر مبنایِ آخرین رویدادِ بازار (last-market-activity-datetime): تاریخ و زمانِ رو بر مبنایِ آخرین رویدادِ بازار رو بهت می‌ده.
</li>
<li>
داده‌هایِ مربوط به سهامدارهایِ درصدی (shareholder_list): داده‌هایِ مربوط به سهامدارهایِ عمده رو استخراج و پالایش می‌کنه.
</li>
<li>
تعدیلِ قیمت (adjust_price_flow): قیمتِ تعدیلی و قبلِ تعدیل نمادهایی که قیمتشون تعدیل شده رو بهت می‌ده.
</li>
<li>
افزایشِ سرمایه (ins_share_change_flow):  افزایش/تغییرِ سرمایه‌یِ همه‌یِ شرکت‌ها رو بهت می‌ده.
</li>
</div>

<h5 dir="rtl">
لیستِ داده‌هایی در آینده می‌تونی دریافت کنی:
</h5>
<div dir="rtl">
<li>
داده‌هایِ گذشته‌یِ معامله‌هایِ درون-روزی.
</li>

<li>
داده‌هایِ گذشته‌یِ سفارش‌ها-5 مظنه-
</li>

</div>

## TGJU (tgju.org)
<div dir="rtl">
داده‌هایِ طلا و دلارِ وب-سایتِ tsetmc.com رو پوشش می‌ده. و در آینده کالاهایی که به بورسِ ایران مربوطه و از آنجا قابلِ دریافته رو پوشش خواهد داد. 
<br>
<br>
نمونه (برای راهنمایِ کامل 
<a href="https://yghaderi.github.io/oxtapus/">
راهنمایِ بهره-گیران
</a>
رو بخونید)
:
</div>

```python
>>> from oxtapus import TGJU

>>> tgju = TGJU()
>>> tgju.usd_irr()
shape: (3_688, 6)
┌────────────┬────────────┬──────────┬──────────┬──────────┬──────────┐
│ date       ┆ jdate      ┆ open     ┆ high     ┆ low      ┆ close    │
│ ---        ┆ ---        ┆ ---      ┆ ---      ┆ ---      ┆ ---      │
│ date       ┆ str        ┆ f64      ┆ f64      ┆ f64      ┆ f64      │
╞════════════╪════════════╪══════════╪══════════╪══════════╪══════════╡
│ 2023-11-01 ┆ 1402-08-10 ┆ 514870.0 ┆ 517900.0 ┆ 513380.0 ┆ 516830.0 │
│ 2023-10-31 ┆ 1402-08-09 ┆ 516770.0 ┆ 518060.0 ┆ 515370.0 ┆ 516600.0 │
│ 2023-10-30 ┆ 1402-08-08 ┆ 511950.0 ┆ 514600.0 ┆ 510650.0 ┆ 514500.0 │
│ 2023-10-29 ┆ 1402-08-07 ┆ 519550.0 ┆ 519560.0 ┆ 513350.0 ┆ 513560.0 │
│ …          ┆ …          ┆ …        ┆ …        ┆ …        ┆ …        │
│ 2011-11-29 ┆ 1390-09-08 ┆ 13400.0  ┆ 13400.0  ┆ 13400.0  ┆ 13400.0  │
│ 2011-11-28 ┆ 1390-09-07 ┆ 13350.0  ┆ 13350.0  ┆ 13350.0  ┆ 13350.0  │
│ 2011-11-27 ┆ 1390-09-06 ┆ 13440.0  ┆ 13440.0  ┆ 13440.0  ┆ 13440.0  │
│ 2011-11-26 ┆ 1390-09-05 ┆ 13700.0  ┆ 13700.0  ┆ 13700.0  ┆ 13700.0  │
└────────────┴────────────┴──────────┴──────────┴──────────┴──────────┘
```


<h5 dir="rtl">
لیستِ داده‌هایِ قابلِ دریافت:
</h5>
<div dir="rtl">
<li>
دلار/ریال (usd/irr)
</li>

<li>
سکه‌یِ امامی (sekke-emami)
</li>

<li>
نیم-سکه (nim-sekke)
</li>

<li>
ربعِ-سکه (rob-sekke) 
</li>

<li>
اونسِ طلا (ons)
</li>

</div>



<a href="https://metafid.com/sponsor">
       <img src="http://www.coffeete.ir/images/buttons/lemonchiffon.png" style="width:260px;" />
</a>